==> dojo_1.15.4+dfsg1.orig.tar.xz: dojo-release-1.15.4-src/dojo/cldr/nls/tr/hebrew.js <==
define(
//begin v1.x content
{
	"field-tue-relative+-1": "geçen salı",
	"field-year": "yıl",
	"field-wed-relative+0": "bu çarşamba",
	"field-wed-relative+1": "gelecek çarşamba",
	"field-minute": "dakika",
	"field-month-narrow-relative+-1": "geçen ay",
	"field-tue-narrow-relative+0": "bu salı",
	"field-tue-narrow-relative+1": "gelecek salı",
	"field-thu-short-relative+0": "bu per.",
	"field-day-short-relative+-1": "dün",
	"field-thu-short-relative+1": "gelecek per.",
	"field-day-relative+0": "bugün",
	"field-day-short-relative+-2": "evvelsi gün",
	"field-day-relative+1": "yarın",
	"field-day-relative+2": "öbür gün",
	"field-wed-narrow-relative+-1": "geçen çar.",
	"field-year-narrow": "yıl",
	"field-year-narrow-relative+0": "bu yıl",
	"field-tue-relative+0": "bu salı",
	"field-year-narrow-relative+1": "gelecek yıl",
	"field-tue-relative+1": "gelecek salı",
	"field-second-short": "sn.",
	"dayPeriods-format-narrow-am": "öö",
	"dateFormatItem-MMMd": "d MMM",
	"dayPeriods-format-abbr-am": "ÖÖ",
	"field-week-relative+0": "bu hafta",
	"field-month-relative+0": "bu ay",
	"field-week-relative+1": "gelecek hafta",
	"field-month-relative+1": "gelecek ay",
	"field-sun-narrow-relative+0": "bu paz.",
	"field-mon-short-relative+0": "bu pzt.",
	"field-sun-narrow-relative+1": "gelecek paz.",
	"field-mon-short-relative+1": "gelecek pzt.",
	"field-second-relative+0": "şimdi",
	"dateFormatItem-yyyyQQQ": "G y/QQQ",
	"dayPeriods-standAlone-abbr-pm": "ÖS",
	"field-month-short": "ay",
	"dateFormatItem-GyMMMEd": "G d MMM y E",
	"dateFormatItem-yyyyMd": "GGGGG dd.MM.y",
	"field-day": "gün",
	"field-year-relative+-1": "geçen yıl",
	"dayPeriods-format-wide-am": "ÖÖ",
	"field-sat-short-relative+-1": "geçen cmt.",
	"field-hour-relative+0": "bu saat",
	"dateFormatItem-yyyyMEd": "GGGGG dd.MM.y E",
	"field-wed-relative+-1": "geçen çarşamba",
	"field-sat-narrow-relative+-1": "geçen cmt.",
	"field-second": "saniye",
	"days-standAlone-narrow": [
		"P",
		"P",
		"S",
		"Ç",
		"P",
		"C",
		"C"
	],
	"dayPeriods-standAlone-wide-pm": "ÖS",
	"dateFormat-long": "G d MMMM y",
	"dateFormatItem-GyMMMd": "G d MMM y",
	"field-quarter": "çeyrek",
	"field-week-short": "hf.",
	"field-day-narrow-relative+0": "bugün",
	"field-day-narrow-relative+1": "yarın",
	"field-day-narrow-relative+2": "öbür gün",
	"quarters-standAlone-wide": [
		"1. çeyrek",
		"2. çeyrek",
		"3. çeyrek",
		"4. çeyrek"
	],
	"days-format-narrow": [
		"P",
		"P",
		"S",
		"Ç",
		"P",
		"C",
		"C"
	],
	"field-tue-short-relative+0": "bu salı",
	"field-tue-short-relative+1": "gelecek salı",
	"field-month-short-relative+-1": "geçen ay",
	"field-mon-relative+-1": "geçen pazartesi",
	"dateFormatItem-GyMMM": "G MMM y",
	"field-month": "ay",
	"field-day-narrow": "gün",
	"field-minute-short": "dk.",
	"field-dayperiod": "ÖÖ/ÖS",
	"field-sat-short-relative+0": "bu cmt.",
	"field-sat-short-relative+1": "gelecek cmt.",
	"dayPeriods-format-narrow-pm": "ös",
	"dateFormat-medium": "G d MMM y",
	"dateFormatItem-yyyyMMMM": "G MMMM y",
	"quarters-standAlone-abbr": [
		"Ç1",
		"Ç2",
		"Ç3",
		"Ç4"
	],
	"dayPeriods-format-abbr-pm": "ÖS",
	"dateFormatItem-yyyyM": "GGGGG M/y",
	"field-second-narrow": "sn.",
	"field-mon-relative+0": "bu pazartesi",
	"field-mon-relative+1": "gelecek pazartesi",
	"field-day-narrow-relative+-1": "dün",
	"field-year-short": "yıl",
	"field-day-narrow-relative+-2": "evvelsi gün",
	"field-quarter-relative+-1": "geçen çeyrek",
	"dateFormatItem-yyyyMMMd": "G dd MMM y",
	"dayPeriods-standAlone-narrow-am": "ÖÖ",
	"days-format-short": [
		"Pa",
		"Pt",
		"Sa",
		"Ça",
		"Pe",
		"Cu",
		"Ct"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "ÖS",
	"field-sat-relative+-1": "geçen cumartesi",
	"dateFormatItem-Md": "dd/MM",
	"field-hour": "saat",
	"months-format-wide": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Veadar",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"dateFormat-full": "G d MMMM y EEEE",
	"field-month-relative+-1": "geçen ay",
	"field-quarter-short": "çyr.",
	"field-sat-narrow-relative+0": "bu cmt.",
	"field-fri-relative+0": "bu cuma",
	"field-sat-narrow-relative+1": "gelecek cmt.",
	"field-fri-relative+1": "gelecek cuma",
	"field-month-narrow-relative+0": "bu ay",
	"field-month-narrow-relative+1": "gelecek ay",
	"field-sun-short-relative+0": "bu paz.",
	"field-sun-short-relative+1": "gelecek paz.",
	"field-week-relative+-1": "geçen hafta",
	"months-format-abbr": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Veadar",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"field-quarter-relative+0": "bu çeyrek",
	"field-minute-relative+0": "bu dakika",
	"field-quarter-relative+1": "gelecek çeyrek",
	"field-wed-short-relative+-1": "geçen çar.",
	"dateFormat-short": "GGGGG d.MM.y",
	"field-thu-short-relative+-1": "geçen per.",
	"field-year-narrow-relative+-1": "geçen yıl",
	"days-standAlone-wide": [
		"Pazar",
		"Pazartesi",
		"Salı",
		"Çarşamba",
		"Perşembe",
		"Cuma",
		"Cumartesi"
	],
	"dateFormatItem-yyyyMMMEd": "G d MMM y E",
	"field-mon-narrow-relative+-1": "geçen pzt.",
	"dateFormatItem-MMMMd": "dd MMMM",
	"field-thu-narrow-relative+-1": "geçen per.",
	"field-tue-narrow-relative+-1": "geçen salı",
	"dayPeriods-standAlone-narrow-pm": "ÖS",
	"field-wed-short-relative+0": "bu çar.",
	"months-standAlone-wide": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Veadar",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"field-wed-short-relative+1": "gelecek çar.",
	"field-sun-relative+-1": "geçen pazar",
	"days-standAlone-abbr": [
		"Paz",
		"Pzt",
		"Sal",
		"Çar",
		"Per",
		"Cum",
		"Cmt"
	],
	"field-weekday": "haftanın günü",
	"field-day-short-relative+0": "bugün",
	"field-sat-relative+0": "bu cumartesi",
	"field-day-short-relative+1": "yarın",
	"field-sat-relative+1": "gelecek cumartesi",
	"field-day-short-relative+2": "öbür gün",
	"months-standAlone-abbr": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Veadar",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"months-format-wide-leap": "Adar II",
	"field-month-short-relative+0": "bu ay",
	"field-month-short-relative+1": "gelecek ay",
	"dateFormatItem-MEd": "dd/MM E",
	"field-thu-narrow-relative+0": "bu per.",
	"field-thu-narrow-relative+1": "gelecek per.",
	"field-sun-narrow-relative+-1": "geçen paz.",
	"field-mon-short-relative+-1": "geçen pzt.",
	"field-thu-relative+0": "bu perşembe",
	"field-thu-relative+1": "gelecek perşembe",
	"field-fri-short-relative+-1": "geçen cuma",
	"field-thu-relative+-1": "geçen perşembe",
	"field-week": "hafta",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"1. çeyrek",
		"2. çeyrek",
		"3. çeyrek",
		"4. çeyrek"
	],
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "bu çar.",
	"field-wed-narrow-relative+1": "gelecek çar.",
	"field-year-short-relative+0": "bu yıl",
	"dateFormatItem-yyyyMMM": "G MMM y",
	"field-year-short-relative+1": "gelecek yıl",
	"field-fri-short-relative+0": "bu cuma",
	"field-fri-short-relative+1": "gelecek cuma",
	"days-standAlone-short": [
		"Pa",
		"Pt",
		"Sa",
		"Ça",
		"Pe",
		"Cu",
		"Ct"
	],
	"dateFormatItem-yyyyQQQQ": "G y/QQQQ",
	"field-hour-short": "sa.",
	"quarters-format-abbr": [
		"Ç1",
		"Ç2",
		"Ç3",
		"Ç4"
	],
	"field-month-narrow": "ay",
	"field-hour-narrow": "sa.",
	"field-fri-narrow-relative+-1": "geçen cuma",
	"field-year-relative+0": "bu yıl",
	"field-year-relative+1": "gelecek yıl",
	"field-fri-relative+-1": "geçen cuma",
	"field-tue-short-relative+-1": "geçen salı",
	"field-minute-narrow": "dk.",
	"days-format-wide": [
		"Pazar",
		"Pazartesi",
		"Salı",
		"Çarşamba",
		"Perşembe",
		"Cuma",
		"Cumartesi"
	],
	"field-mon-narrow-relative+0": "bu pzt.",
	"field-mon-narrow-relative+1": "gelecek pzt.",
	"field-year-short-relative+-1": "geçen yıl",
	"field-zone": "saat dilimi",
	"dateFormatItem-MMMEd": "d MMM E",
	"field-quarter-narrow": "çyr.",
	"field-sun-short-relative+-1": "geçen paz.",
	"field-day-relative+-1": "dün",
	"dayPeriods-standAlone-abbr-am": "ÖÖ",
	"field-day-relative+-2": "evvelsi gün",
	"days-format-abbr": [
		"Paz",
		"Pzt",
		"Sal",
		"Çar",
		"Per",
		"Cum",
		"Cmt"
	],
	"field-sun-relative+0": "bu pazar",
	"field-sun-relative+1": "gelecek pazar",
	"field-day-short": "gün",
	"field-week-narrow": "hf.",
	"field-era": "Miladi Dönem",
	"field-fri-narrow-relative+0": "bu cuma",
	"field-fri-narrow-relative+1": "gelecek cuma",
	"dayPeriods-standAlone-wide-am": "ÖÖ"
}
//end v1.x content
);

==> dojo_1.17.2+dfsg1.orig.tar.xz: dojo-release-1.17.2-src/dojo/cldr/nls/tr/hebrew.js <==
define(
//begin v1.x content
{
	"field-quarter-short-relative+0": "bu çyr.",
	"field-quarter-short-relative+1": "gelecek çyr.",
	"field-tue-relative+-1": "geçen salı",
	"field-year": "yıl",
	"field-wed-relative+0": "bu çarşamba",
	"field-wed-relative+1": "gelecek çarşamba",
	"field-minute": "dakika",
	"field-month-narrow-relative+-1": "geçen ay",
	"field-tue-narrow-relative+0": "bu salı",
	"field-tue-narrow-relative+1": "gelecek salı",
	"field-thu-short-relative+0": "bu per.",
	"field-day-short-relative+-1": "dün",
	"field-thu-short-relative+1": "gelecek per.",
	"field-day-relative+0": "bugün",
	"field-day-short-relative+-2": "evvelsi gün",
	"field-day-relative+1": "yarın",
	"field-week-narrow-relative+0": "bu hf.",
	"field-day-relative+2": "öbür gün",
	"field-week-narrow-relative+1": "gelecek hf.",
	"field-wed-narrow-relative+-1": "geçen çar.",
	"dateFormatItem-EBhms": "E B h:mm:ss",
	"field-year-narrow": "yıl",
	"field-era-short": "çağ",
	"field-year-narrow-relative+0": "bu yıl",
	"field-tue-relative+0": "bu salı",
	"field-year-narrow-relative+1": "gelecek yıl",
	"field-tue-relative+1": "gelecek salı",
	"field-weekdayOfMonth": "ayın günü",
	"field-second-short": "sn.",
	"dayPeriods-format-narrow-am": "öö",
	"dateFormatItem-MMMd": "d MMM",
	"field-weekdayOfMonth-narrow": "ayın günü",
	"dayPeriods-format-abbr-am": "ÖÖ",
	"field-week-relative+0": "bu hafta",
	"field-month-relative+0": "bu ay",
	"field-week-relative+1": "gelecek hafta",
	"field-month-relative+1": "gelecek ay",
	"field-sun-narrow-relative+0": "bu paz.",
	"field-mon-short-relative+0": "bu pzt.",
	"field-sun-narrow-relative+1": "gelecek paz.",
	"field-mon-short-relative+1": "gelecek pzt.",
	"field-second-relative+0": "şimdi",
	"dateFormatItem-yyyyQQQ": "G y/QQQ",
	"eraNames": [
		"AM"
	],
	"field-weekOfMonth": "ayın haftası",
	"dayPeriods-standAlone-abbr-pm": "ÖS",
	"field-month-short": "ay",
	"dateFormatItem-GyMMMEd": "G d MMM y E",
	"dateFormatItem-yyyyMd": "GGGGG dd.MM.y",
	"field-day": "gün",
	"field-dayOfYear-short": "yılın günü",
	"field-year-relative+-1": "geçen yıl",
	"dayPeriods-format-wide-am": "ÖÖ",
	"field-sat-short-relative+-1": "geçen cmt.",
	"field-hour-relative+0": "bu saat",
	"dateFormatItem-yyyyMEd": "GGGGG dd.MM.y E",
	"field-wed-relative+-1": "geçen çarşamba",
	"field-sat-narrow-relative+-1": "geçen cmt.",
	"field-second": "saniye",
	"days-standAlone-narrow": [
		"P",
		"P",
		"S",
		"Ç",
		"P",
		"C",
		"C"
	],
	"dayPeriods-standAlone-wide-pm": "ÖS",
	"dateFormat-long": "G d MMMM y",
	"dateFormatItem-GyMMMd": "G d MMM y",
	"field-quarter": "çeyrek",
	"field-week-short": "hf.",
	"field-day-narrow-relative+0": "bugün",
	"field-day-narrow-relative+1": "yarın",
	"field-day-narrow-relative+2": "öbür gün",
	"quarters-standAlone-wide": [
		"1. çeyrek",
		"2. çeyrek",
		"3. çeyrek",
		"4. çeyrek"
	],
	"days-format-narrow": [
		"P",
		"P",
		"S",
		"Ç",
		"P",
		"C",
		"C"
	],
	"field-tue-short-relative+0": "bu salı",
	"field-tue-short-relative+1": "gelecek salı",
	"field-month-short-relative+-1": "geçen ay",
	"field-mon-relative+-1": "geçen pazartesi",
	"dateFormatItem-GyMMM": "G MMM y",
	"field-month": "ay",
	"field-day-narrow": "gün",
	"field-minute-short": "dk.",
	"field-dayperiod": "ÖÖ/ÖS",
	"field-sat-short-relative+0": "bu cmt.",
	"field-sat-short-relative+1": "gelecek cmt.",
	"dayPeriods-format-narrow-pm": "ös",
	"dateFormat-medium": "G d MMM y",
	"dateFormatItem-yyyyMMMM": "G MMMM y",
	"eraAbbr": [
		"AM"
	],
	"quarters-standAlone-abbr": [
		"Ç1",
		"Ç2",
		"Ç3",
		"Ç4"
	],
	"dayPeriods-format-abbr-pm": "ÖS",
	"dateFormatItem-yyyyM": "GGGGG M/y",
	"field-second-narrow": "sn.",
	"field-mon-relative+0": "bu pazartesi",
	"field-mon-relative+1": "gelecek pazartesi",
	"field-day-narrow-relative+-1": "dün",
	"field-year-short": "yıl",
	"field-day-narrow-relative+-2": "evvelsi gün",
	"field-quarter-relative+-1": "geçen çeyrek",
	"dateFormatItem-yyyyMMMd": "G dd MMM y",
	"field-dayperiod-narrow": "ÖÖ/ÖS",
	"dayPeriods-standAlone-narrow-am": "ÖÖ",
	"field-week-narrow-relative+-1": "geçen hf.",
	"days-format-short": [
		"Pa",
		"Pt",
		"Sa",
		"Ça",
		"Pe",
		"Cu",
		"Ct"
	],
	"quarters-format-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"dayPeriods-format-wide-pm": "ÖS",
	"field-dayOfYear": "yılın günü",
	"field-sat-relative+-1": "geçen cumartesi",
	"dateFormatItem-Md": "dd/MM",
	"field-hour": "saat",
	"months-format-wide": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Adar Rişon",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"dateFormat-full": "G d MMMM y EEEE",
	"field-month-relative+-1": "geçen ay",
	"field-quarter-short": "çyr.",
	"field-sat-narrow-relative+0": "bu cmt.",
	"field-fri-relative+0": "bu cuma",
	"field-sat-narrow-relative+1": "gelecek cmt.",
	"field-fri-relative+1": "gelecek cuma",
	"dateFormatItem-EBhm": "E B h:mm",
	"field-month-narrow-relative+0": "bu ay",
	"field-month-narrow-relative+1": "gelecek ay",
	"field-sun-short-relative+0": "bu paz.",
	"field-sun-short-relative+1": "gelecek paz.",
	"field-week-relative+-1": "geçen hafta",
	"field-quarter-short-relative+-1": "geçen çyr.",
	"months-format-abbr": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Adar Rişon",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"field-quarter-relative+0": "bu çeyrek",
	"field-minute-relative+0": "bu dakika",
	"field-quarter-relative+1": "gelecek çeyrek",
	"field-wed-short-relative+-1": "geçen çar.",
	"dateFormat-short": "GGGGG d.MM.y",
	"dateFormatItem-Bh": "B h",
	"field-thu-short-relative+-1": "geçen per.",
	"field-year-narrow-relative+-1": "geçen yıl",
	"days-standAlone-wide": [
		"Pazar",
		"Pazartesi",
		"Salı",
		"Çarşamba",
		"Perşembe",
		"Cuma",
		"Cumartesi"
	],
	"dateFormatItem-yyyyMMMEd": "G d MMM y E",
	"field-mon-narrow-relative+-1": "geçen pzt.",
	"dateFormatItem-MMMMd": "dd MMMM",
	"field-thu-narrow-relative+-1": "geçen per.",
	"field-tue-narrow-relative+-1": "geçen salı",
	"field-weekOfMonth-short": "ayın haftası",
	"dayPeriods-standAlone-narrow-pm": "ÖS",
	"field-wed-short-relative+0": "bu çar.",
	"months-standAlone-wide": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Adar Rişon",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"field-wed-short-relative+1": "gelecek çar.",
	"field-sun-relative+-1": "geçen pazar",
	"days-standAlone-abbr": [
		"Paz",
		"Pzt",
		"Sal",
		"Çar",
		"Per",
		"Cum",
		"Cmt"
	],
	"months-format-abbr-leap": "Veadar",
	"field-weekday": "haftanın günü",
	"field-day-short-relative+0": "bugün",
	"field-quarter-narrow-relative+0": "bu çyr.",
	"field-day-short-relative+1": "yarın",
	"field-sat-relative+0": "bu cumartesi",
	"field-quarter-narrow-relative+1": "gelecek çyr.",
	"field-day-short-relative+2": "öbür gün",
	"field-sat-relative+1": "gelecek cumartesi",
	"field-week-short-relative+0": "bu hf.",
	"field-week-short-relative+1": "gelecek hf.",
	"months-standAlone-abbr": [
		"Tişri",
		"Heşvan",
		"Kislev",
		"Tevet",
		"Şevat",
		"Adar Rişon",
		"Adar",
		"Nisan",
		"İyar",
		"Sivan",
		"Tamuz",
		"Av",
		"Elul"
	],
	"months-format-wide-leap": "Veadar",
	"field-dayOfYear-narrow": "yılın günü",
	"field-month-short-relative+0": "bu ay",
	"field-month-short-relative+1": "gelecek ay",
	"field-weekdayOfMonth-short": "ayın günü",
	"dateFormatItem-MEd": "dd/MM E",
	"field-zone-narrow": "dilim",
	"field-thu-narrow-relative+0": "bu per.",
	"field-thu-narrow-relative+1": "gelecek per.",
	"field-sun-narrow-relative+-1": "geçen paz.",
	"field-mon-short-relative+-1": "geçen pzt.",
	"field-thu-relative+0": "bu perşembe",
	"field-thu-relative+1": "gelecek perşembe",
	"field-fri-short-relative+-1": "geçen cuma",
	"field-thu-relative+-1": "geçen perşembe",
	"field-week": "hafta",
	"quarters-standAlone-narrow": [
		"1.",
		"2.",
		"3.",
		"4."
	],
	"quarters-format-wide": [
		"1. çeyrek",
		"2. çeyrek",
		"3. çeyrek",
		"4. çeyrek"
	],
	"dateFormatItem-Ed": "d E",
	"field-wed-narrow-relative+0": "bu çar.",
	"field-wed-narrow-relative+1": "gelecek çar.",
	"field-quarter-narrow-relative+-1": "geçen çyr.",
	"field-year-short-relative+0": "bu yıl",
	"field-dayperiod-short": "ÖÖ/ÖS",
	"dateFormatItem-yyyyMMM": "G MMM y",
	"field-year-short-relative+1": "gelecek yıl",
	"field-fri-short-relative+0": "bu cuma",
	"field-fri-short-relative+1": "gelecek cuma",
	"days-standAlone-short": [
		"Pa",
		"Pt",
		"Sa",
		"Ça",
		"Pe",
		"Cu",
		"Ct"
	],
	"field-week-short-relative+-1": "geçen hf.",
	"months-standAlone-abbr-leap": "Veadar",
	"dateFormatItem-yyyyQQQQ": "G y/QQQQ",
	"field-hour-short": "sa.",
	"field-zone-short": "dilim",
	"quarters-format-abbr": [
		"Ç1",
		"Ç2",
		"Ç3",
		"Ç4"
	],
	"field-month-narrow": "ay",
	"field-hour-narrow": "sa.",
	"field-fri-narrow-relative+-1": "geçen cuma",
	"field-year-relative+0": "bu yıl",
	"field-year-relative+1": "gelecek yıl",
	"field-era-narrow": "çağ",
	"field-fri-relative+-1": "geçen cuma",
	"eraNarrow": "AM",
	"dateFormatItem-Bhms": "B h:mm:ss",
	"field-tue-short-relative+-1": "geçen salı",
	"field-minute-narrow": "dk.",
	"days-format-wide": [
		"Pazar",
		"Pazartesi",
		"Salı",
		"Çarşamba",
		"Perşembe",
		"Cuma",
		"Cumartesi"
	],
	"field-mon-narrow-relative+0": "bu pzt.",
	"field-mon-narrow-relative+1": "gelecek pzt.",
	"field-year-short-relative+-1": "geçen yıl",
	"field-zone": "saat dilimi",
	"dateFormatItem-MMMEd": "d MMM E",
	"field-weekOfMonth-narrow": "ayın haftası",
	"field-weekday-narrow": "haftanın günü",
	"months-standAlone-wide-leap": "Veadar",
	"field-quarter-narrow": "çyr.",
	"field-sun-short-relative+-1": "geçen paz.",
	"field-day-relative+-1": "dün",
	"dayPeriods-standAlone-abbr-am": "ÖÖ",
	"field-day-relative+-2": "evvelsi gün",
	"field-weekday-short": "haftanın günü",
	"days-format-abbr": [
		"Paz",
		"Pzt",
		"Sal",
		"Çar",
		"Per",
		"Cum",
		"Cmt"
	],
	"dateFormatItem-Bhm": "B h:mm",
	"field-sun-relative+0": "bu pazar",
	"field-sun-relative+1": "gelecek pazar",
	"field-day-short": "gün",
	"field-week-narrow": "hf.",
	"field-era": "çağ",
	"field-fri-narrow-relative+0": "bu cuma",
	"field-fri-narrow-relative+1": "gelecek cuma",
	"dayPeriods-standAlone-wide-am": "ÖÖ"
}
//end v1.x content
);
